@@ -1,8 +1,14 @@
 import json
 import time
-
+import os
 import requests
 
+#pylint: disable=import-error
+if os.environ.get('SERVER_SOFTWARE','').startswith('Google'):
+    import requests_toolbelt.adapters.appengine
+    requests_toolbelt.adapters.appengine.monkeypatch()
+#pylint: enable=import-error
+
 import px_constants
 import px_httpc
 import px_utils
@@ -35,13 +41,19 @@ def send_risk_request(ctx, config):
     }
     try:
         response = px_httpc.send(full_url=config.server_host + px_constants.API_RISK, body=json.dumps(body),
-                                 config=config,
-                                 headers=default_headers, method='POST')
-        return json.loads(response.content)
+                                 config=config, headers=default_headers, method='POST', raise_error = True)
+        if response:
+            return json.loads(response.content)
+        return False
     except requests.exceptions.Timeout:
+        ctx.pass_reason = 's2s_timeout'
         risk_rtt = time.time() - start
-        config.logger('Risk API timed out, round_trip_time: {}'.format(risk_rtt))
-
+        config.logger.debug('Risk API timed out, round_trip_time: {}'.format(risk_rtt))
+        return False
+    except requests.exceptions.RequestException as e:
+        ctx.pass_reason = 's2s_error'
+        config.logger.debug('Unexpected exception in Risk API call: {}'.format(e))
+        return False
 
 def verify(ctx, config):
     """
@@ -65,6 +77,9 @@ def verify(ctx, config):
             ctx.risk_rtt = risk_rtt
             ctx.pxde = response.get('data_enrichment', {})
             ctx.pxde_verified = True
+            response_pxhd = response.get('pxhd', '')
+            #Do not set cookie if there's already a valid pxhd
+            ctx.response_pxhd = response_pxhd
             if ctx.score >= config.blocking_score:
                 if response.get('action') == px_constants.ACTION_CHALLENGE and \
                         response.get('action_data') is not None and \
@@ -115,13 +130,15 @@ def prepare_risk_body(ctx, config):
     }
     if ctx.vid:
         body['vid'] = ctx.vid
-        body['vid_source'] = ctx.vid_source
+        body['additional']['enforcer_vid_source'] = ctx.enforcer_vid_source
     if ctx.uuid:
         body['uuid'] = ctx.uuid
     if ctx.cookie_hmac:
         body['additional']['px_cookie_hmac'] = ctx.cookie_hmac
     if ctx.cookie_names:
         body['additional']['request_cookie_names'] = ctx.cookie_names
+    if ctx.pxhd:
+        body['pxhd'] = ctx.pxhd
 
     body = add_original_token_data(ctx, body)
 
@@ -129,7 +146,7 @@ def prepare_risk_body(ctx, config):
 
     if ctx.s2s_call_reason == 'cookie_decryption_failed':
         logger.debug('attaching orig_cookie to request')
-        body['additional']['px_orig_cookie'] = ctx.px_orig_cookie
+        body['additional']['px_cookie_raw'] = ctx.px_cookie_raw
 
     if ctx.s2s_call_reason in ['cookie_expired', 'cookie_validation_failed']:
         logger.debug('attaching px_cookie to request')
